/*
 Copyright (C) 2008  Goldmund, Wyldebeast & Wunderliebe

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
*/
ul.sortable li {
  width: 100%;
  position: relative;
}

ul.boxy {
  height: 100%;
  width: 100%;
  list-style-type: none;
  list-style-image: none;
  margin: 0px;
}

ul.narrow {
  height: 100%;
  list-style-type: none;
  list-style-image: none;
  margin: 0px;
  width: 50%;
}

ul.narrow li .viewlet-title{
 cursor: default !important;
}

#content ul.boxy a[href^="http:"], 
#content ul.boxy a.link-external, 
#content ul.narrow a.link-external, 
#content ul.narrow  a[href^="http:"] {
  background: transparent none repeat scroll 0%;
  padding:0px;
}

ul.boxy li {
  position: relative;
}

ul.boxy li a {
  background: none !important;
  padding: 0px !important;
}
.clickable-icon {
  cursor: pointer;
}

/**
 * Container styling
 */

.viewlet-container {
  padding: 0px;
  margin: 0px;
  position: relative;
}

.viewlet-container table th {
  text-align:  left;
  padding-right: 5px;
  padding-left: 5px;
}

/* switch off portlet styling when used within viewlets */
.viewlet-container dl dt.portletHeader,
.viewlet-container dl dd.portletFooter {
  display:none;
}

.viewlet-container dl dd.portletItem,
.viewlet-container .portlet {
  border: none;
}

/**
 * Toolbar styling
 */

.viewlet-toolbar {
  color: #8CACBB;
  height: 30px;
  xpadding: 0px;
  border: solid 1px #8CACBB;
  background-color: #DEE7EC;
  background-image: url('viewlet-title-background.png');
}

#menu .viewlet-toolbar {
  background-image: none;
}


.viewlet-title {
  width:100%;
  padding-left: 10px;
  padding-top: 5px;
  font-size: 10px;
  font-weight: bold;
  cursor: move;
  text-transform: lowercase;
  text-align: left;
  float: left;
}

li.nodrag .viewlet-toolbar .viewlet-title {
  cursor: default;
}

.viewlet-toolbar .toolbar a,
.viewlet-toolbar .toolbar div {
  position: absolute;
  top: 2px;
  display: block;
  width: 16px;
  height: 16px;
  overflow: hidden;
}

.viewlet-container .toggleicon .minimized {
  background: url('collapse.gif') !important;
  display: block !important;
}

.viewlet-container .minimized {
  display: none !important;
}

.viewlet-toolbar .toolbar .toggleicon .toggle {
  background: url('expand.gif');
  background-repeat: no-repeat;
}

.viewlet-toolbar .toolbar .toggleicon {
  margin-top: 4px;
  right: 45px;
}

/* Hide from IE-Mac \*/
.viewlet-toolbar .toolbar .help {
  margin-top: 4px;
  right: 65px;
  background: url('help.gif') no-repeat;
}
/* End hide */

.viewlet-toolbar .toolbar .remove {
  margin-top: 4px;
  right: 25px;
  background: url('close.gif') no-repeat;
}

.viewlet-toolbar .toolbar .remove-locked {
  margin-top: 4px;
  right: 25px;
  background: url('lock.gif') no-repeat;
}

/**
 * Content styling
 */

.viewlet-content {
  clear: both;
  color: #8CACBB;
  font-size: 10px;
  overflow: hidden;
  background-color: #FFFFFF;
  position: relative;
  border: solid 1px #8CACBB;
  border-top: 0px;
  padding: 10px;
  padding-top:5px;
}

.viewlet-content h1,h2,h3 {
  color: #8CACBB;
}

.viewlet-content a {
  border-bottom: none !important;
}


/**
 * Help styling
 */
.viewlet-help-container {
  clear: both;
  position: absolute;
  top: 0px;
  left: 0px;
  width: 100%;
  overflow: hidden;
  background: transparent;
  z-index: 1;
}

.viewlet-help {
  padding-bottom: 20px;
  background: url('bottom-border-blue.png') repeat-x bottom;
}

.viewlet-help .help {
  background-color: #89ABCC;
  color: #FFFFFF;
  padding-left:5px;
  padding-right:5px;
}


/**
 * mlango-dashboard. This is the main panel, that is a container for the UL
 * elements that hold the dragable list items.
 */

 
#mlango-dashboard {
  background-color: #FFFFFF;
  border-right: 1px solid #8CACBB;
  margin-top: 5px;
  margin-bottom: 5px;
  xheight: 1000px;
  position: relative;
  overflow: hidden;
  padding-right: 25px;
}

.mlango-dashboard-col {
  height: 1000px;
  float: left;
  position: relative;
}

.mlango-dashboard-col {
  margin-left: 0.5em;
}

/**
 * Menu pane styling. The menu pane is the sliding panel, holding the actual
 * menu.
 */

#menupane {
  position: absolute;
  top: 20px;
  right: 0px;
  width: 200px;
  padding: 0px;
}

#menu {
  font-size: 10px;
  background: url('menu-back-gradient.png');
  padding: 0px;
  width: 200px;
  display: block;
  position: absolute;
  top: 0px;
  left: 190px;
  margin-top: 15%;
  padding-bottom: 20px;
  background-color: #F5F2EF;
  border-style: solid;
  border-color: #8CACBB;
  border-width: 1px 0px 1px 1px;
}

#menu .legend {
  margin-left: 1.5em;
  float: left;
  width: 150px;
}

#menu .legend td {
  background-color: #FFFFFF;
}

#menuinfo {
  color: #8CACBB;
  font-weight: bold;
  font-size: 1em;
  position: absolute;
  top: 1.5em;
  right: 4em;
  padding-top: 20px;
  padding-left: 10px;
  padding-right: 0em;
  width: 15em;
  height: 12em;
  display: block;
  background: url('balloon.gif');
  background-repeat: no-repeat;
  filter: alpha(opacity=75);
  opacity: 0.75;
}

#menupane #menu h3 {
  padding: 10px;
}

#menupane ul li div.viewlet-content {
  display: none !important;
}

#menugrabbing {
  float: left;
  clear: both;
}

#menutitle {
  margin-left: 20px;
  color: #8CACBB;
  text-transform: lowercase;
  font-weight: bold;
}


.viewlet-listing {
  list-style-type: none !important;
  list-style-image: none !important;
}

.viewlet-listing .toolbar, .viewlet-listing .viewlet-content {
  display: none;
}

.hiddenItem {
  display: none !important;
}

.viewlet-listing .viewlet-toolbar {
  border: none;
  background-color: transparent;
  padding: 0px;
}

.viewlet-listing .viewlet-title {
  background: url('grabber.png') repeat-y;
  background-color: #FFFFFF;
  height: 2em;
}

.viewlet-listing .viewlet-container {
  background-color: transparent;
}

.viewlet-listing .viewlet-title {
  width: auto;
  border: 1px solid #8CACBB;
  padding: 6px 10px 2px 20px;
}

.viewlet-listing .toolbar {
  margin-right: 0px;
}

#col_listing li {
  float: left;
  clear: both;
}

.copyright {
  padding-top: 10px;
  padding-left: 0px;
  color: #DEE7EC;
  background-color: #89ABCC;
  font-size: 0.7em;
  font-weight: bold;
  text-transform: lowercase;
}

.portalMessage {
  clear: both;
  margin-right: 15px;
  margin-left: 5px;
  margin-bottom: 0px;
}

.mlango-action {
  float: left;
  margin-left: 5px;
  margin-bottom: 5px;
}

/**
 * Dummy style.
 */

#mlango-dummy {
  border: 1px dashed #d0d0ff;
  position: relative;
}

#col_listing #mlango-dummy {
  display: none;
}

/**
 * A background empty
 */

.mlango-dashboard-col a {
background: none !important;
padding-left:0px !important;
padding-right:0px !important;
}








