# -*- coding: utf-8 -*-

from zope.interface import Interface

##code-section HEAD
##/code-section HEAD

class IMlangoDashboard(Interface):
    """Marker interface for .MlangoDashboard.MlangoDashboard
    """

class IMlangoViewlet(Interface):
    """Marker interface for .MlangoViewlet.MlangoViewlet
    """

class IMlangoRSSViewlet(Interface):
    """Marker interface for .MlangoRSSViewlet.MlangoRSSViewlet
    """

class IMlangoCustomViewlet(Interface):
    """Marker interface for .MlangoCustomViewlet.MlangoCustomViewlet
    """

##code-section FOOT
##/code-section FOOT