# -*- coding: utf-8 -*-

from zope.interface import Interface

##code-section HEAD
##/code-section HEAD

class IMlangoTool(Interface):
    """Marker interface for .MlangoTool.MlangoTool
    """

##code-section FOOT
##/code-section FOOT