/*
 Copyright (C) 2008  Goldmund, Wyldebeast & Wunderliebe

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
*/

/**
 * Borders
 */

#menu .border-top-left,
#menu .border-top-right,
#menu .border-bottom-left,
#menu .border-bottom-right {
  display:none;
}

#menu .viewlet-container {
  border: none;
}

.border-top-left {
  height: 9px;
  width: 9px;
  border: 0px;
  position: absolute;
  left: 0px;
  top: 0px;
  z-index: 5;
  background: transparent url("border-top-left.gif") top left no-repeat;
}

.border-top-right {
  height: 9px;
  width: 9px;
  border: 0px;
  position: absolute;
  top: 0px;
  right: 0px;
  z-index: 5;
  background: transparent url("border-top-right.gif") top right no-repeat;
}

.border-bottom-left {
  height: 9px;
  width: 9px;
  border: 0px;
  position: absolute;
  bottom: 0px;
  left: 0px;
  z-index: 5;
  background: transparent url("border-bottom-left.gif") bottom left no-repeat;
}

.border-bottom-right {
  position: absolute;
  bottom: 0px;
  border: 0px;
  right: 0px;
  height: 9px;
  width: 100%;
  margin-right: 0;
  z-index: 5;
  background: transparent url("border-bottom-right.gif") bottom right no-repeat;
}
